=======
History
=======

0.0.4 (2017-06-27)
------------------

* zkpytb.utils: add hashstring() and get_git_hash() helpers.
* Add tests for zkpytb.dicts and zkpytb.utils modules.

0.0.3 (2017-06-23)
------------------

* Add first version of zkpytb.logging module with function setup_simple_console_and_file_logger().

0.0.2 (2017-06-22)
------------------

* Disable universal wheel.

0.0.1 (2017-06-22)
------------------

* First release on PyPI.
